Index: /trunk/src/VBox/Main/include/EmulatedUSBImpl.h
===================================================================
--- /trunk/src/VBox/Main/include/EmulatedUSBImpl.h	(revision 50579)
+++ /trunk/src/VBox/Main/include/EmulatedUSBImpl.h	(revision 50580)
@@ -43,12 +43,12 @@
 
     /* Public method for internal use. */
-    static DECLCALLBACK(int) eusbCallback(void *pv, const char *pszId, uint32_t iEvent,
-                                          const void *pvData, uint32_t cbData);
+    static DECLCALLBACK(int) i_eusbCallback(void *pv, const char *pszId, uint32_t iEvent,
+                                            const void *pvData, uint32_t cbData);
 
-    HRESULT webcamAttachInternal(const com::Utf8Str &aPath,
-                                 const com::Utf8Str &aSettings,
-                                 const char *pszDriver,
-                                 void *pvObject);
-    HRESULT webcamDetachInternal(const com::Utf8Str &aPath);
+    HRESULT i_webcamAttachInternal(const com::Utf8Str &aPath,
+                                   const com::Utf8Str &aSettings,
+                                   const char *pszDriver,
+                                   void *pvObject);
+    HRESULT i_webcamDetachInternal(const com::Utf8Str &aPath);
 
 private:
Index: /trunk/src/VBox/Main/src-client/UsbWebcamInterface.cpp
===================================================================
--- /trunk/src/VBox/Main/src-client/UsbWebcamInterface.cpp	(revision 50579)
+++ /trunk/src/VBox/Main/src-client/UsbWebcamInterface.cpp	(revision 50580)
@@ -259,5 +259,5 @@
         /* Try to attach the device. */
         EmulatedUSB *pEUSB = mParent->getConsole()->getEmulatedUSB();
-        pEUSB->webcamAttachInternal("", "", "EmWebcam", pRemote);
+        pEUSB->i_webcamAttachInternal("", "", "EmWebcam", pRemote);
     }
     else

Index: /trunk/src/VBox/Main/src-client/EmulatedUSBImpl.cpp
===================================================================
--- /trunk/src/VBox/Main/src-client/EmulatedUSBImpl.cpp	(revision 50579)
+++ /trunk/src/VBox/Main/src-client/EmulatedUSBImpl.cpp	(revision 50580)
@@ -157,5 +157,5 @@
     CFGMR3InsertNode(pConfig,       "EmulatedUSB", &pEUSB);
     CFGMR3InsertString(pEUSB,         "Id", pThis->mszUuid);
-    CFGMR3InsertInteger(pEUSB,        "pfnCallback", (uintptr_t)EmulatedUSB::eusbCallback);
+    CFGMR3InsertInteger(pEUSB,        "pfnCallback", (uintptr_t)EmulatedUSB::i_eusbCallback);
     CFGMR3InsertInteger(pEUSB,        "pvCallback", (uintptr_t)pThis->mpEmulatedUSB);
 
@@ -442,11 +442,11 @@
                                   const com::Utf8Str &aSettings)
 {
-    return webcamAttachInternal(aPath, aSettings, "HostWebcam", NULL);
-}
-
-HRESULT EmulatedUSB::webcamAttachInternal(const com::Utf8Str &aPath,
-                                          const com::Utf8Str &aSettings,
-                                          const char *pszDriver,
-                                          void *pvObject)
+    return i_webcamAttachInternal(aPath, aSettings, "HostWebcam", NULL);
+}
+
+HRESULT EmulatedUSB::i_webcamAttachInternal(const com::Utf8Str &aPath,
+                                            const com::Utf8Str &aSettings,
+                                            const char *pszDriver,
+                                            void *pvObject)
 {
     HRESULT hrc = S_OK;
@@ -524,8 +524,8 @@
 HRESULT EmulatedUSB::webcamDetach(const com::Utf8Str &aPath)
 {
-    return webcamDetachInternal(aPath);
-}
-
-HRESULT EmulatedUSB::webcamDetachInternal(const com::Utf8Str &aPath)
+    return i_webcamDetachInternal(aPath);
+}
+
+HRESULT EmulatedUSB::i_webcamDetachInternal(const com::Utf8Str &aPath)
 {
     HRESULT hrc = S_OK;
@@ -605,6 +605,6 @@
 }
 
-/* static */ DECLCALLBACK(int) EmulatedUSB::eusbCallback(void *pv, const char *pszId, uint32_t iEvent,
-                                                         const void *pvData, uint32_t cbData)
+/* static */ DECLCALLBACK(int) EmulatedUSB::i_eusbCallback(void *pv, const char *pszId, uint32_t iEvent,
+                                                           const void *pvData, uint32_t cbData)
 {
     /* Make a copy of parameters, forward to EMT and leave the callback to not hold any lock in the device. */